API docs for “spamfighter.core.commands.partner.PartneredCommand”

# Class s.c.c.p.PartneredCommand(Command):

Part of spamfighter.core.commands.partner View Source View In Hierarchy

Known subclasses: spamfighter.core.commands.partner.DomainedCommand, spamfighter.core.commands.test.test_partner.FakePartneredCommand

Команда, обязательным параметром которой является партнер. Команда автоматически осуществляет авторизацию партнера.

Instance Variables | partner | партнер, авторизованный для данной команды (type: `spamfighter.interfaces.IPartner` )

Method | init | Дополнительный метод, может переопределяться в потомках для выполнения процедуры

Inherited from Command:

Method | __init__ | Конструктор команды
Method | getResponse | Сформировать результат команды как хэш, готовый к XML-RPC преобразованию.
Method | getParams | Сформировать параметры команды как хэш, готовый к XML-RPC преобразованию.
Method | checkParams | Проверить наличие всех необходимых параметров команды.
Method | checkResult | Проверить наличие всех необходимых полей в результате выполнения команды.
Method | finalize | Дополнительный метод, может переопределяться в потомках для выполнения завершения
Method | run | Выполнить команду.
Class | _ParamsWrapper | Класс-обертка для проверки корректности

def init(self): (source)
overrides spamfighter.core.commands.command.Command.init
overridden in spamfighter.core.commands.partner.DomainedCommand
Дополнительный метод, может переопределяться в потомках для выполнения процедуры дополнительной предварительной инициализации.

Определяем партнера по механизму авторизации партнеров.